|PyPI| |Docs| |Build Status| |Coverage|

.. |PyPI| image:: https://img.shields.io/pypi/v/anndata.svg
   :target: https://pypi.org/project/anndata
.. |Docs| image:: https://readthedocs.com/projects/icb-anndata/badge/?version=latest
   :target: https://anndata.readthedocs.io
.. |Build Status| image:: https://travis-ci.org/theislab/anndata.svg?branch=master
   :target: https://travis-ci.org/theislab/anndata
.. |Coverage| image:: https://codecov.io/gh/theislab/anndata/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/theislab/anndata

anndata - Annotated Data
========================

Install via ``pip install anndata`` or ``conda install anndata -c bioconda``.

Read the `documentation <https://anndata.readthedocs.io>`_.

.. would be nice to have http://falexwolf.de/img/scanpy/anndata.svg also on GitHub, but it's much too wide there;
.. GitHub doesn't plan to resolve scaling images: https://github.com/github/markup/issues/295
